![tests](https://github.com/ephios-dev/ephios/workflows/tests/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/ephios/badge/?version=latest)](https://docs.ephios.de/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/ephios)](https://pypi.org/project/ephios/)
[![Coverage Status](https://coveralls.io/repos/github/ephios-dev/ephios/badge.svg?branch=main)](https://coveralls.io/github/ephios-dev/ephios?branch=main)
[![translated by Weblate](https://hosted.weblate.org/widgets/ephios/-/svg-badge.svg)](https://hosted.weblate.org/engage/ephios/)


# ephios

ephios is a tool to manage shifts for medical services.
Planners can create events for which volunteer help is required (e.g. security/medical services, beach patrols, exercises).
An event can contain multiple shifts for which different processes can be applied for signup 
(e.g. a direct confirmation for an event or an "application" that has to be accepted first).
The volunteers can register for the respective shifts via a clearly arranged web interface.
The planners can then assign personnel and have an overview of the current status.
Around this central feature there are further supporting functions like the management of the volunteers and their
qualifications or an overview of the volunteer hours worked. A flexible group systems helps to support complex permission
szenarios. The functionality can be extended using plugins.

## Documentation
You can find the documentation for ephios at [Read the Docs](https://docs.ephios.de/en/latest). This includes
the user guide and installation instructions.

## Contributing
Contributions to ephios are very welcome. You can find information about contributing at our [Contribution page](https://docs.ephios.de/en/latest/development/contributing.html)
We are using Weblate for translations, you can also contribute [there](https://hosted.weblate.org/engage/ephios/).
